import { Graph } from "@antv/x6";
import { printHandle } from "./index";
import { handleInsertText } from './hander';

export const bindKeys = (graph: Graph) => {
  // Ctrl + A 全选
  graph.bindKey('ctrl+a', (e: KeyboardEvent) => {
    e.stopPropagation();

    graph.getCells().forEach((cell) => {
      if(!cell.getData()?.isPage) {
        graph.select(cell);
      }
    });
  });

  // Ctrl + F 查找替换 todo
  graph.bindKey('ctrl+f', (e: KeyboardEvent) => {
    e.stopPropagation();

  });

  // Ctrl + + 放大
  graph.bindKey('ctrl+=', (e: KeyboardEvent) => {
    e.stopPropagation();

    graph.zoomTo(graph.zoom() + 0.1);
  });

  // Ctrl + - 缩小
  graph.bindKey('ctrl+-', (e: KeyboardEvent) => {
    e.stopPropagation();

    graph.zoomTo(graph.zoom() - 0.1);
  });

  // esc 取消
  graph.bindKey('esc', (e: KeyboardEvent) => {
    e.stopPropagation();

    graph.cleanSelection();
    graph.trigger('cancel');
  });

  // Ctrl + P 打印
  graph.bindKey('ctrl+p', (e: KeyboardEvent) => {
    e.stopPropagation();

    graph.toPNG((dataUri) => {
      printHandle(dataUri);
    })
  });

  // T 插入文本
  graph.bindKey('t', (e: KeyboardEvent) => {
    e.stopPropagation();

    handleInsertText(graph);
  });
};